:mod:`npdl.optimizers`
=======================

.. automodule:: npdl.optimizers


Optimizers
----------

.. autosummary::
   :nosignatures:

    SGD
    Momentum
    NesterovMomentum
    Adagrad
    RMSprop
    Adadelta
    Adam
    Adamax


Detailed Description
--------------------

.. autoclass:: SGD
   :members:

.. autoclass:: Momentum
   :members:

.. autoclass:: NesterovMomentum
   :members:

.. autoclass:: Adagrad
   :members:

.. autoclass:: RMSprop
   :members:

.. autoclass:: Adadelta
   :members:

.. autoclass:: Adam
   :members:

.. autoclass:: Adamax
   :members:



